@@ -121,6 +121,8 @@ class QueryTickets:
 
         # response = requests.get(url + payload)
 
+        print(url + payload)
+
         # print(response.text)
         if response["status_code"] != 200:
             raise HTTPError("Failed to query all tickets", response)
@@ -130,15 +132,19 @@ class QueryTickets:
         for page in range(1, (result["total_pages"] + 1)):
             for ticket_in_data in result["data"]:
                 # print(ticket_in_data)
-                creator = User(
-                    user_id=ticket_in_data["created_by_user"]["id"],
-                    first_name=ticket_in_data["created_by_user"]["first_name"],
-                    last_name=ticket_in_data["created_by_user"]["last_name"],
-                    job_title=ticket_in_data["created_by_user"]["job_title"],
-                    email=ticket_in_data["created_by_user"]["email"],
-                )
-                if ticket_in_data["created_by_user"]["title"]:
-                    creator.title = ticket_in_data["created_by_user"]["title"]["name"]
+                creator = None
+                if ticket_in_data["created_by_user"]:
+                    creator = User(
+                        user_id=ticket_in_data["created_by_user"]["id"],
+                        first_name=ticket_in_data["created_by_user"]["first_name"],
+                        last_name=ticket_in_data["created_by_user"]["last_name"],
+                        job_title=ticket_in_data["created_by_user"]["job_title"],
+                        email=ticket_in_data["created_by_user"]["email"],
+                    )
+                    if ticket_in_data["created_by_user"]["title"]:
+                        creator.title = ticket_in_data["created_by_user"]["title"][
+                            "name"
+                        ]
 
                 owner = None
                 if ticket_in_data["customer_user"]:
@@ -161,7 +167,9 @@ class QueryTickets:
                     )
 
                 account_vp = None
-                if ticket_in_data["account"] and (ticket_in_data["account"] is not None):
+                if ticket_in_data["account"] and (
+                    ticket_in_data["account"] is not None
+                ):
                     account_vp = ticket_in_data["account"]["id"]
 
                 ticket = Ticket(
@@ -188,7 +196,7 @@ class QueryTickets:
                     owner=owner,
                     creator=creator,
                     assignee=assignee,
-                    visible_to_customer=ticket_in_data["visible_to_customer"],
+                    internal=ticket_in_data["internal"],
                     ticket_type=TicketType(
                         type_id=ticket_in_data["type"]["id"],
                         name=ticket_in_data["type"]["name"],
@@ -255,7 +263,21 @@ def statement(left: str) -> str:
 
 
 def comparison(left: str, operator: str, right: str) -> str:
-    valid_operators = ["=", ">", "<", ">=", "<=", "<>", "CONTAINS", "NOT CONTAINS", "IN", "OR", "NOT"]
+    valid_operators = [
+        "=",
+        ">",
+        "<",
+        ">=",
+        "<=",
+        "<>",
+        "CONTAINS",
+        "NOT CONTAINS",
+        "IN",
+        "OR",
+        "NOT",
+    ]
     if operator not in valid_operators:
-        raise Exception("Invalid operator. Valid operators include: " + str(valid_operators))
+        raise Exception(
+            "Invalid operator. Valid operators include: " + str(valid_operators)
+        )
     return str(left) + "%20" + str(operator) + "%20" + str(right)
